Crate ext4 [] [src]

This crate can load ext4 filesystems, letting you read metadata and files from them.

Example

let mut superblock = SuperBlock::new(&mut part_reader).unwrap();
let target_inode_number = superblock.resolve_path("/etc/passwd").unwrap().inode;
let inode = superblock.load_inode(target_inode_number).unwrap();
let passwd_reader = superblock.open(&nice_node).unwrap();

Modules

mbr

Support for reading MBR (not GPT) partition tables, and getting an io::Read for a partition.

Structs

DirEntry

An entry in a directory, without its extra metadata.

Error

The Error type.

Inode

An actual disc metadata entry.

Stat

Full information about a disc entry.

SuperBlock

The critical core of the filesystem.

Time

A raw filesystem time.

Enums

Enhanced

Extended, type-specific information read from an inode.

ErrorKind

The kind of an error.

FileType

Flag indicating the type of file stored in this inode.

Traits

ResultExt

Additional methods for Result, for easy interaction with this crate.

Type Definitions

Result

Convenient wrapper around std::Result.